aboutsummaryrefslogtreecommitdiff
path: root/scripts/rpki/resource_set.py
diff options
context:
space:
mode:
authorRob Austein <sra@hactrn.net>2007-11-14 17:22:06 +0000
committerRob Austein <sra@hactrn.net>2007-11-14 17:22:06 +0000
commit8d48fee8d4f99bcd07c8def5fdc4a5cbb302ae35 (patch)
tree50c6596a54b0cba28bdccf5d3ff6f5b0343653a2 /scripts/rpki/resource_set.py
parentd8cc553708a7cc662d3f33d5efa270ecb2bfa513 (diff)
Rewrite child_cert.reissue() to support the full range of actions it
might need to take, from returning the existing cert unchanged to generating a new cert while revoking the old one. svn path=/scripts/biz-certs/Bob-CA.srl; revision=1294
Diffstat (limited to 'scripts/rpki/resource_set.py')
-rw-r--r--scripts/rpki/resource_set.py8
1 files changed, 5 insertions, 3 deletions
diff --git a/scripts/rpki/resource_set.py b/scripts/rpki/resource_set.py
index a98824b8..795c695d 100644
--- a/scripts/rpki/resource_set.py
+++ b/scripts/rpki/resource_set.py
@@ -434,17 +434,19 @@ class resource_bag(object):
return not (self == other)
def intersection(self, other):
"""Compute intersection with another resource_bag."""
return self.__class__(self.as.intersection(other.as),
self.v4.intersection(other.v4),
- self.v6.intersection(other.v6))
+ self.v6.intersection(other.v6),
+ self.valid_until)
# Test suite for set operations. This will probably go away eventually
if __name__ == "__main__":
def test(t, s1, s2):
- """Lame unit test."""
print
r1 = t(s1)
r2 = t(s2)
@@ -434,17 +434,19 @@ class resource_bag(object):
return not (self == other)
def intersection(self, other):
- """Compute intersection with another resource_bag."""
+ """Compute intersection with another resource_bag.
+ valid_until attribute (if any) inherits from self.
+ """
return self.__class__(self.as.intersection(other.as),
self.v4.intersection(other.v4),